Module create_token_pool

Module create_token_pool 

Structs

AddTokenPoolInstruction
Creates an SPL or token-2022 token pool account, which is owned by the token authority PDA.
AddTokenPoolInstructionBumps
CreateTokenPoolInstruction
Creates an SPL or token-2022 token pool account, which is owned by the token authority PDA.
CreateTokenPoolInstructionBumps

Functions

assert_mint_extensions
check_spl_token_pool_derivation
Checks if the token pool PDA is valid. Iterates over all possible bump seeds to check if the token pool PDA is valid.
check_spl_token_pool_derivation_with_index
find_token_pool_pda_with_index
get_token_pool_pda
get_token_pool_pda_with_index